# 🌐 QGIS

🌐 an AI terraform for [QGIS](https://www.qgis.org/).

```bash
pip install blue-geo
```

```bash
QGIS help
```
--help-- blue_geo QGIS

to terraform QGIS, generate the seed 🌱,

```bash
QGIS seed
```

and paste it in the Python Console in QGIS.

![image](https://github.com/kamangir/assets/blob/main/blue-geo/QGIS-python-console.png?raw=true)

![image](https://raw.githubusercontent.com/kamangir/assets/main/blue-geo/QGIS.png)